@@ -40,9 +40,23 @@ function(libname, pkgname)
  .initClasses()
 }
 
+.onUnload <- function(libpath) {
+  .gtkCleanup()
+  library.dynam.unload("RGtk2", libpath)
+}
+
 .windows_gtk_path <- function()
   file.path(system.file(package = "RGtk2"), "gtk", .Platform$r_arch)
 
+.configure_gtk_theme <- function(theme) {
+  ## Only applies to Windows so far
+  config_path <- file.path(system.file(package = "RGtk2"), "gtk",
+                           .Platform$r_arch, "etc", "gtk-2.0")
+  dir.create(config_path, recursive = TRUE)
+  writeLines(sprintf("gtk-theme-name = \"%s\"", theme),
+             file.path(config_path, "gtkrc"))
+}
+
 .install_system_dependencies <- function()
 {
   windows32_config <-
@@ -54,6 +68,7 @@ function(libname, pkgname)
            ## unzip does this, but we want to see any warnings
            dir.create(gtk_path, recursive = TRUE) 
            unzip(path, exdir = gtk_path)
+           .configure_gtk_theme("MS-Windows")
          }
          )
 
@@ -62,7 +77,7 @@ function(libname, pkgname)
   
   darwin_config <- list(
     source = FALSE,
-    gtk_url = "http://r.research.att.com/libs/GTK_2.18.5-X11.pkg", 
+    gtk_url = "http://r.research.att.com/libs/GTK_2.24.17-X11.pkg", 
     installer = function(path) {
       system(paste("open", path))
     }
